==> ksmoothdock-3.6.1.tar.gz: ksmoothdock/src/welcomedialog.cpp <==
/***************************************************************************
                          welcomedialog.cpp  -  description
                             -------------------
    begin                : May 7 22:18:34 BST 2004
    copyright            : (C) 2003-2005 by KSmoothDock team
    email                : dangvd@yahoo.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#include <klocale.h>

#include <qvariant.h>
#include <qgroupbox.h>
#include <qlabel.h>
#include <qbuttongroup.h>
#include <qradiobutton.h>
#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qcombobox.h>

#include "welcomedialog.h"

/*
 *  Constructs a WelcomeDialog as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
WelcomeDialog::WelcomeDialog( QWidget* parent, const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl )
{
    if ( !name )
	setName( "WelcomeDialog" );

    textLabel2 = new QLabel( this, "textLabel2" );
    textLabel2->setGeometry( QRect( 20, 60, 490, 41 ) );

    groupBox1 = new QGroupBox( this, "groupBox1" );
    groupBox1->setGeometry( QRect( 20, 110, 490, 100 ) );

    buttonGroup2 = new QButtonGroup( groupBox1, "buttonGroup2" );
    buttonGroup2->setGeometry( QRect( 20, 30, 340, 60 ) );
    buttonGroup2->setLineWidth( 0 );

    rbNormalZoom = new QRadioButton( buttonGroup2, "rbNormalZoom" );
    rbNormalZoom->setGeometry( QRect( 10, 0, 16, 16 ) );
    rbNormalZoom->setChecked( TRUE );

    textLabel3 = new QLabel( buttonGroup2, "textLabel3" );
    textLabel3->setGeometry( QRect( 60, -12, 221, 41 ) );

    textLabel4 = new QLabel( buttonGroup2, "textLabel4" );
    textLabel4->setGeometry( QRect( 60, 20, 180, 40 ) );

    rbParabolicZoom = new QRadioButton( buttonGroup2, "rbParabolicZoom" );
    rbParabolicZoom->setGeometry( QRect( 10, 31, 20, 20 ) );

    groupBox2 = new QGroupBox( this, "groupBox2" );
    groupBox2->setGeometry( QRect( 20, 220, 490, 190 ) );

    cbClock = new QCheckBox( groupBox2, "cbClock" );
    cbClock->setGeometry( QRect( 30, 160, 16, 16 ) );

    cbPager = new QCheckBox( groupBox2, "cbPager" );
    cbPager->setGeometry( QRect( 30, 70, 16, 16 ) );

    textLabel6 = new QLabel( groupBox2, "textLabel6" );
    textLabel6->setGeometry( QRect( 80, 20, 340, 41 ) );

    cbQuickLaunch = new QCheckBox( groupBox2, "cbQuickLaunch" );
    cbQuickLaunch->setEnabled( FALSE );
    cbQuickLaunch->setGeometry( QRect( 30, 30, 16, 21 ) );
    cbQuickLaunch->setChecked( TRUE );

    textLabel7 = new QLabel( groupBox2, "textLabel7" );
    textLabel7->setGeometry( QRect( 80, 63, 171, 31 ) );

    textLabel2_3 = new QLabel( groupBox2, "textLabel2_3" );
    textLabel2_3->setGeometry( QRect( 80, 103, 131, 31 ) );

    cbShowWinAllDesks = new QCheckBox( groupBox2, "cbShowWinAllDesks" );
    cbShowWinAllDesks->setGeometry( QRect( 110, 134, 16, 16 ) );

    textLabel1_3 = new QLabel( groupBox2, "textLabel1_3" );
    textLabel1_3->setGeometry( QRect( 160, 122, 261, 41 ) );

    textLabel9 = new QLabel( groupBox2, "textLabel9" );
    textLabel9->setGeometry( QRect( 80, 154, 141, 30 ) );

    cbTaskbar = new QCheckBox( groupBox2, "cbTaskbar" );
    cbTaskbar->setGeometry( QRect( 30, 110, 16, 16 ) );

    pushButton3 = new QPushButton( this, "pushButton3" );
    pushButton3->setGeometry( QRect( 210, 510, 121, 41 ) );

    groupBox22 = new QGroupBox( this, "groupBox22" );
    groupBox22->setGeometry( QRect( 20, 430, 490, 60 ) );

    textLabel5_3 = new QLabel( groupBox22, "textLabel5_3" );
    textLabel5_3->setGeometry( QRect( 80, 20, 261, 30 ) );

    cbAutohide = new QCheckBox( groupBox22, "cbAutohide" );
    cbAutohide->setGeometry( QRect( 30, 26, 20, 20 ) );

    textLabel1 = new QLabel( this, "textLabel1" );
    textLabel1->setGeometry( QRect( 20, 0, 490, 61 ) );
    languageChange();
    resize( QSize(530, 568).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );

    // signals and slots connections
    connect( pushButton3, SIGNAL( clicked() ), this, SLOT( pushButton3_clicked() ) );
    connect( cbTaskbar, SIGNAL( stateChanged(int) ), this, SLOT( cbTaskbar_stateChanged(int) ) );

    // init variables
    cbShowWinAllDesks->setEnabled(cbTaskbar->isChecked());
}

/*
 *  Destroys the object and frees any allocated resources
 */
WelcomeDialog::~WelcomeDialog()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void WelcomeDialog::languageChange()
{
    setCaption( tr2i18n( "Welcome to KSmoothDock!" ) );
    textLabel2->setText( tr2i18n( "<font color=\"#aa0000\">Note: you can always change these options (as well as other options) later by right-click on the dock,\n"
"then click on \"Edit Preferences\".</font>" ) );
    groupBox1->setTitle( tr2i18n( "The zooming mode you want to use" ) );
    buttonGroup2->setTitle( QString::null );
    rbNormalZoom->setText( tr2i18n( "radioButton1" ) );
    textLabel3->setText( tr2i18n( "Normal Smooth Zooming Mode" ) );
    textLabel4->setText( tr2i18n( "Parabolic Zooming Mode" ) );
    rbParabolicZoom->setText( tr2i18n( "radioButton2" ) );
    groupBox2->setTitle( tr2i18n( "The components of KSmoothDock you want to use" ) );
    cbClock->setText( tr2i18n( "checkBox4" ) );
    cbPager->setText( QString::null );
    textLabel6->setText( tr2i18n( "Quick launch menu (always enabled by default)" ) );
    cbQuickLaunch->setText( QString::null );
    textLabel7->setText( tr2i18n( "Pager" ) );
    textLabel2_3->setText( tr2i18n( "Taskbar" ) );
    cbShowWinAllDesks->setText( tr2i18n( "checkBox5" ) );
    textLabel1_3->setText( tr2i18n( "Show windows from all desktops" ) );
    textLabel9->setText( tr2i18n( "Clock" ) );
    cbTaskbar->setText( tr2i18n( "checkBox3" ) );    
    pushButton3->setText( tr2i18n( "&OK" ) );
    pushButton3->setAccel( QKeySequence( tr2i18n( "Alt+O" ) ) );
    groupBox22->setTitle( tr2i18n( "Hiding" ) );
    textLabel5_3->setText( tr2i18n( "Hide automatically" ) );
    cbAutohide->setText( tr2i18n( "checkBox11" ) );
    textLabel1->setText( tr2i18n( "<font color=\"#0000ff\">It seems you are running KSmoothDock 3.6 for the first time!<br>\n"
"Please choose your initial basic setup.</font>" ) );
}

void WelcomeDialog::pushButton3_clicked()
{
  accept();
}

void WelcomeDialog::cbTaskbar_stateChanged( int )
{
  cbShowWinAllDesks->setEnabled(cbTaskbar->isChecked());
}

int WelcomeDialog::getZoomMode() {
    int zoomMode = (rbNormalZoom->isOn()) ? NORMAL_ZOOM : PARABOLIC_ZOOM;
    return zoomMode;
}

int WelcomeDialog::getShowPager() {
    int showPager = (cbPager->isChecked()) ? 1 : 0;
    return showPager;
}

int WelcomeDialog::getShowTaskbar() {    
    int showTaskbar = (cbTaskbar->isChecked()) ? 1 : 0;
    return showTaskbar;
}

int WelcomeDialog::getShowClock() {
    int showClock = (cbClock->isChecked()) ? 1 : 0;
    return showClock;
}

int WelcomeDialog::getShowWinAllDesks() {
		int res = (cbShowWinAllDesks->isChecked()) ? 1 : 0;
    return res;
}

int WelcomeDialog::getAutohide() {
  return cbAutohide->isChecked();
}

==> ksmoothdock-4.0.1.tar.gz: ksmoothdock/src/welcomedialog.cpp <==
/***************************************************************************
                          welcomedialog.cpp  -  description
                             -------------------
    begin                : May 7 22:18:34 BST 2004
    copyright            : (C) 2003-2005 by KSmoothDock team
    email                : dangvd@yahoo.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

/// @TODO: re-format the file according to KSmoothDock v4.0's coding style

#include <klocale.h>

#include <qvariant.h>
#include <qgroupbox.h>
#include <qlabel.h>
#include <qbuttongroup.h>
#include <qradiobutton.h>
#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qcombobox.h>

#include "welcomedialog.h"

/*
 *  Constructs a WelcomeDialog as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
WelcomeDialog::WelcomeDialog( QWidget* parent, const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl )
{
    if ( !name )
	setName( "WelcomeDialog" );

    textLabel2 = new QLabel( this, "textLabel2" );
    textLabel2->setGeometry( QRect( 20, 60, 490, 41 ) );

    groupBox1 = new QGroupBox( this, "groupBox1" );
    groupBox1->setGeometry( QRect( 20, 110, 490, 100 ) );

    buttonGroup2 = new QButtonGroup( groupBox1, "buttonGroup2" );
    buttonGroup2->setGeometry( QRect( 20, 30, 340, 60 ) );
    buttonGroup2->setLineWidth( 0 );

    rbNormalZoom = new QRadioButton( buttonGroup2, "rbNormalZoom" );
    rbNormalZoom->setGeometry( QRect( 10, 0, 16, 16 ) );
    rbNormalZoom->setChecked( TRUE );

    textLabel3 = new QLabel( buttonGroup2, "textLabel3" );
    textLabel3->setGeometry( QRect( 60, -12, 221, 41 ) );

    textLabel4 = new QLabel( buttonGroup2, "textLabel4" );
    textLabel4->setGeometry( QRect( 60, 20, 180, 40 ) );

    rbParabolicZoom = new QRadioButton( buttonGroup2, "rbParabolicZoom" );
    rbParabolicZoom->setGeometry( QRect( 10, 31, 20, 20 ) );

    groupBox2 = new QGroupBox( this, "groupBox2" );
    groupBox2->setGeometry( QRect( 20, 220, 490, 190 ) );

    cbClock = new QCheckBox( groupBox2, "cbClock" );
    cbClock->setGeometry( QRect( 30, 160, 16, 16 ) );

    cbPager = new QCheckBox( groupBox2, "cbPager" );
    cbPager->setGeometry( QRect( 30, 70, 16, 16 ) );

    textLabel6 = new QLabel( groupBox2, "textLabel6" );
    textLabel6->setGeometry( QRect( 80, 20, 340, 41 ) );

    cbQuickLaunch = new QCheckBox( groupBox2, "cbQuickLaunch" );
    cbQuickLaunch->setEnabled( FALSE );
    cbQuickLaunch->setGeometry( QRect( 30, 30, 16, 21 ) );
    cbQuickLaunch->setChecked( TRUE );

    textLabel7 = new QLabel( groupBox2, "textLabel7" );
    textLabel7->setGeometry( QRect( 80, 63, 171, 31 ) );

    textLabel2_3 = new QLabel( groupBox2, "textLabel2_3" );
    textLabel2_3->setGeometry( QRect( 80, 103, 131, 31 ) );

    cbShowWinAllDesks = new QCheckBox( groupBox2, "cbShowWinAllDesks" );
    cbShowWinAllDesks->setGeometry( QRect( 110, 134, 16, 16 ) );

    textLabel1_3 = new QLabel( groupBox2, "textLabel1_3" );
    textLabel1_3->setGeometry( QRect( 160, 122, 261, 41 ) );

    textLabel9 = new QLabel( groupBox2, "textLabel9" );
    textLabel9->setGeometry( QRect( 80, 154, 141, 30 ) );

    cbTaskbar = new QCheckBox( groupBox2, "cbTaskbar" );
    cbTaskbar->setGeometry( QRect( 30, 110, 16, 16 ) );

    pushButton3 = new QPushButton( this, "pushButton3" );
    pushButton3->setGeometry( QRect( 210, 510, 121, 41 ) );

    textLabel1 = new QLabel( this, "textLabel1" );
    textLabel1->setGeometry( QRect( 20, 0, 490, 61 ) );
    languageChange();
    resize( QSize(530, 568).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );

    // signals and slots connections
    connect( pushButton3, SIGNAL( clicked() ), this, SLOT( pushButton3_clicked() ) );
    connect( cbTaskbar, SIGNAL( stateChanged(int) ), this, SLOT( cbTaskbar_stateChanged(int) ) );

    // init variables
    cbPager->setChecked(true);
    cbTaskbar->setChecked(true);
    cbClock->setChecked(true);
    cbShowWinAllDesks->setEnabled(cbTaskbar->isChecked());
    cbShowWinAllDesks->setChecked(true);
}

/*
 *  Destroys the object and frees any allocated resources
 */
WelcomeDialog::~WelcomeDialog()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void WelcomeDialog::languageChange()
{
    setCaption( tr2i18n( "Welcome to KSmoothDock!" ) );
    textLabel2->setText( tr2i18n( "<font color=\"#aa0000\">Note: you can always change these options (as well as other options) later by right-click on the dock,\n"
"then click on \"Edit Preferences\".</font>" ) );
    groupBox1->setTitle( tr2i18n( "The zooming mode you want to use" ) );
    buttonGroup2->setTitle( QString::null );
    rbNormalZoom->setText( tr2i18n( "radioButton1" ) );
    textLabel3->setText( tr2i18n( "Normal Smooth Zooming Mode" ) );
    textLabel4->setText( tr2i18n( "Parabolic Zooming Mode" ) );
    rbParabolicZoom->setText( tr2i18n( "radioButton2" ) );
    groupBox2->setTitle( tr2i18n( "The components of KSmoothDock you want to use" ) );
    cbClock->setText( tr2i18n( "checkBox4" ) );
    cbPager->setText( QString::null );
    textLabel6->setText( tr2i18n( "Quick launch menu (always enabled by default)" ) );
    cbQuickLaunch->setText( QString::null );
    textLabel7->setText( tr2i18n( "Pager" ) );
    textLabel2_3->setText( tr2i18n( "Taskbar" ) );
    cbShowWinAllDesks->setText( tr2i18n( "checkBox5" ) );
    textLabel1_3->setText( tr2i18n( "Show windows from all desktops" ) );
    textLabel9->setText( tr2i18n( "Clock" ) );
    cbTaskbar->setText( tr2i18n( "checkBox3" ) );    
    pushButton3->setText( tr2i18n( "&OK" ) );
    pushButton3->setAccel( QKeySequence( tr2i18n( "Alt+O" ) ) );
    textLabel1->setText( tr2i18n( "<font color=\"#0000ff\">It seems you are running KSmoothDock for the first time!<br>\n"
"Please choose your initial basic setup.</font>" ) );
}

void WelcomeDialog::pushButton3_clicked()
{
    accept();
}

void WelcomeDialog::cbTaskbar_stateChanged( int )
{
    cbShowWinAllDesks->setEnabled(cbTaskbar->isChecked());
}

ZoomMode WelcomeDialog::getZoomMode() {
    ZoomMode zoomMode = (rbNormalZoom->isOn()) ? NORMAL_ZOOM : PARABOLIC_ZOOM;
    return zoomMode;
}

int WelcomeDialog::isShowingPager() {
    int showPager = (cbPager->isChecked()) ? 1 : 0;
    return showPager;
}

int WelcomeDialog::isShowingTaskbar() {    
    int showTaskbar = (cbTaskbar->isChecked()) ? 1 : 0;
    return showTaskbar;
}

int WelcomeDialog::isShowingClock() {
    int showClock = (cbClock->isChecked()) ? 1 : 0;
    return showClock;
}

int WelcomeDialog::isShowingWindowsAllDesktops() {
	int res = (cbShowWinAllDesks->isChecked()) ? 1 : 0;
    return res;
}

#include "welcomedialog.moc"
